@@ -5,6 +5,10 @@ from ..utils import common_functions as c_f
 
 
 class BaseDataset(torch.utils.data.Dataset):
+    def __init__(self, domain):
+        super().__init__()
+        self.domain = domain
+
     def __len__(self):
         return len(self.img_paths)
 
@@ -15,5 +19,5 @@ class BaseDataset(torch.utils.data.Dataset):
         return img, label
 
     def __repr__(self):
-        extra_repr = f"len={str(self.__len__())}"
+        extra_repr = f"domain={self.domain}\nlen={str(self.__len__())}"
         return c_f.nice_repr(self, extra_repr, {"transform": self.transform})
